const Home = () => import('~/pages/home').then(m => m.default || m)
const Welcome = () => import('~/pages/welcome').then(m => m.default || m)

const Login = () => import('~/pages/auth/login').then(m => m.default || m)
const Register = () => import('~/pages/auth/register').then(m => m.default || m)
const PasswordReset = () => import('~/pages/auth/password/reset').then(m => m.default || m)
const PasswordRequest = () => import('~/pages/auth/password/email').then(m => m.default || m)

const Settings = () => import('~/pages/settings/index').then(m => m.default || m)
const SettingsProfile = () => import('~/pages/settings/profile').then(m => m.default || m)
const SettingsPassword = () => import('~/pages/settings/password').then(m => m.default || m)

export default [
  { path: '/', name: 'welcome', component: Welcome },

  ...middleware('guest', [
    { path: '/login', name: 'login', component: Login },
    { path: '/register', name: 'register', component: Register },
    { path: '/password/reset', name: 'password.request', component: PasswordRequest },
    { path: '/password/reset/:token', name: 'password.reset', component: PasswordReset }
  ]),

  ...middleware('auth', [
    { path: '/home', name: 'home', component: Home },
    { path: '/settings', component: Settings, children: [
      { path: '', redirect: { name: 'settings.profile' }},
      { path: 'profile', name: 'settings.profile', component: SettingsProfile },
      { path: 'password', name: 'settings.password', component: SettingsPassword }
    ] }
  ]),

  // ...middleware('admin', [
  //   { path: '/admin', name: 'admin', component: require('~/pages/admin') }
  // ]),
  // { path: '/example', name: 'example', component: require('~/pages/example'), middleware: ['admin'] },

  { path: '*', component: require('~/pages/errors/404.vue') }
]

/**
 * @param  {String|Array|Function} middleware
 * @param  {Array} routes
 * @return {Array}
 */
function middleware (middleware, routes) {
  if (Array.isArray(middleware)) {
    middleware = [middleware]
  }

  routes.forEach(route => {
    (route.middleware || (route.middleware = [])).unshift(middleware)
  })

  return routes
}
